==> react-iiif-media-player-1.1.1.tgz: package/es/App.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import MediaElementContainer from './containers/MediaElementContainer';
import StructuredNav from './components/StructuredNav';
import ErrorMessage from './components/ErrorMessage';
import { connect } from 'react-redux';
import * as actions from './actions';

var App = function (_Component) {
  _inherits(App, _Component);

  function App() {
    _classCallCheck(this, App);

    return _possibleConstructorReturn(this, _Component.apply(this, arguments));
  }

  App.prototype.componentDidMount = function componentDidMount() {
    var manifestUrl = this.getManifestUrl();
    if (manifestUrl === '') {
      return;
    }
    this.props.getRemoteManifest(manifestUrl);
  };

  App.prototype.getManifestUrl = function getManifestUrl() {
    var el = document.getElementById('avln-iiif-player-root');
    if (!el) {
      return '';
    }
    return el.getAttribute('data-manifest-url');
  };

  App.prototype.render = function render() {
    var _props$getManifest = this.props.getManifest,
        manifest = _props$getManifest.manifest,
        error = _props$getManifest.error;


    if (manifest) {
      return React.createElement(
        'section',
        null,
        React.createElement(MediaElementContainer, { manifest: manifest }),
        React.createElement(StructuredNav, { manifest: manifest })
      );
    }
    if (error) {
      return React.createElement(ErrorMessage, { message: error });
    }
    return React.createElement(
      'p',
      null,
      '...Loading'
    );
  };

  return App;
}(Component);

var mapStateToProps = function mapStateToProps(state) {
  return {
    getManifest: state.getManifest
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    getRemoteManifest: function getRemoteManifest(url) {
      return dispatch(actions.getRemoteManifest(url));
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(App);

==> react-iiif-media-player-1.1.2.tgz: package/es/App.js <==
function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import MediaElementContainer from './containers/MediaElementContainer';
import StructuredNav from './components/StructuredNav';
import ErrorMessage from './components/ErrorMessage';
import { connect } from 'react-redux';
import * as actions from './actions';

var App = function (_Component) {
  _inherits(App, _Component);

  function App() {
    _classCallCheck(this, App);

    return _possibleConstructorReturn(this, _Component.apply(this, arguments));
  }

  App.prototype.componentDidMount = function componentDidMount() {
    var manifestUrl = this.getManifestUrl();
    if (manifestUrl === '') {
      return;
    }
    this.props.updateExternalConfig(this.props.config);
    this.props.getRemoteManifest(manifestUrl);
  };

  App.prototype.getManifestUrl = function getManifestUrl() {
    var el = document.getElementById('iiif-manifest-url');
    if (!el) {
      return '';
    }
    return el.getAttribute('data-manifest-url');
  };

  App.prototype.render = function render() {
    var _props$getManifest = this.props.getManifest,
        manifest = _props$getManifest.manifest,
        error = _props$getManifest.error;


    if (manifest) {
      return React.createElement(
        'section',
        null,
        React.createElement(MediaElementContainer, { manifest: manifest }),
        React.createElement(StructuredNav, { manifest: manifest })
      );
    }
    if (error) {
      return React.createElement(ErrorMessage, { message: error });
    }
    return React.createElement(
      'p',
      null,
      '...Loading'
    );
  };

  return App;
}(Component);

var mapStateToProps = function mapStateToProps(state) {
  return {
    getManifest: state.getManifest
  };
};

var mapDispatchToProps = function mapDispatchToProps(dispatch) {
  return {
    getRemoteManifest: function getRemoteManifest(url) {
      return dispatch(actions.getRemoteManifest(url));
    },
    updateExternalConfig: function updateExternalConfig(config) {
      return dispatch(actions.updateExternalConfig(config));
    }
  };
};

export default connect(mapStateToProps, mapDispatchToProps)(App);
